//************************************************************************
//
// Copyright (c) 1996 Stephen Karg
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Filename:    output.cpp
//
// Programmer:  Steve Karg
//
// Module:      Elevator Simulation
//
// Technical
// Description: This class is responsible for maintaining the commands
//              for output to the screen or printer.
//
// History:  1: 12-Oct-1996: Created file. - Steve Karg
//
//************************************************************************

#include <graphics.h>
#include <conio.h>
#include "main.h"
#include "output.h"

output::output() /* constructor */
{
  driver = (int)VGA;
  mode = (int)VGAHI;
  line_style = SOLID_LINE;
  line_size = NORM_WIDTH;
  line_color = WHITE;
  text_style = SANS_SERIF_FONT;
  text_size = 1;
  text_color = RED;
  text_direction = HORIZ_DIR;
}

void output::Set_Text_Size(int size)
{
  text_size = size;
}

void output::Set_Text_Style(font_names style)
{
  text_style = style;
}

void output::Set_Text_Color(COLORS color)
{
  text_color = color;
}

void output::Set_Text_Direction(int direction)
{
  text_direction = direction;
}

void output::Set_Line_Size(line_widths size)
{
  line_size = size;
}

void output::Set_Line_Style(line_styles style)
{
  line_style = style;
}

void output::Set_Line_Color(COLORS color)
{
  line_color = color;
}

screen_output::screen_output() /* constructor */
{
  registerbgidriver(VIDEO_BGI_DRIVER);
  initgraph(&driver,&mode,"");
  textbackground((int)BLACK);
  driver = (int)VIDEO_DRIVER;
  mode = (int)VIDEO_MODE;
  line_style = SOLID_LINE;
  line_size = NORM_WIDTH;
  line_color = WHITE;
  text_style = SANS_SERIF_FONT;
  text_size = 1;
  text_color = BLACK;
  text_direction = HORIZ_DIR;
  textcolor(text_color);
}

screen_output::~screen_output() /* destructor */
{
  closegraph();
}

void screen_output::Draw_Text(int text_x,int text_y,char *string)
{
  if (text_x >= VIDEO_MAX_X)
	 text_x = VIDEO_MAX_X-1;
  if (text_y >= VIDEO_MAX_Y)
	 text_y = VIDEO_MAX_Y-1;

  switch(text_style)
  {
	 case SANS_SERIF_FONT:
		registerbgifont(sansserif_font);
		break;
	 case GOTHIC_FONT:
		// registerbgifont(gothic_font);
	 case TRIPLEX_FONT:
		// registerbgifont(triplex_font);
	 case SMALL_FONT:
		// registerbgifont(small_font);
	 default:
		break;
  } /* end of text style switch */
  settextstyle(text_style,text_direction,text_size);
  setcolor(text_color);
  moveto(text_x,text_y);
  outtext(string);
}

void screen_output::Draw_Line(int x1,int y1,int x2,int y2)
{
  if (x1 >= VIDEO_MAX_X)
    x1 = VIDEO_MAX_X-1;
  if (y1 >= VIDEO_MAX_Y)
    y1 = VIDEO_MAX_Y-1;
  if (x2 >= VIDEO_MAX_X)
    x2 = VIDEO_MAX_X-1;
  if (y2 >= VIDEO_MAX_Y)
    y2 = VIDEO_MAX_Y-1;

  setcolor(line_color);
  setlinestyle(line_style,0,line_size);
  line(x1,y1,x2,y2);
}

void screen_output::Draw_Circle(int center_x,int center_y,int radius)
{
  if (center_x >= VIDEO_MAX_X)
	 center_x = VIDEO_MAX_X-1;
  if (center_y >= VIDEO_MAX_Y)
	 center_y = VIDEO_MAX_Y-1;

  setcolor(line_color);
  setlinestyle(line_style,0,line_size);
  circle(center_x,center_y,radius);
}

void screen_output::Draw_Rectangle(int left,int top,int right,int bottom)
{
  if (left >= VIDEO_MAX_X)
	 left = VIDEO_MAX_X-1;
  if (top >= VIDEO_MAX_Y)
	 top = VIDEO_MAX_Y-1;
  if (right >= VIDEO_MAX_X)
	 right = VIDEO_MAX_X-1;
  if (bottom >= VIDEO_MAX_Y)
	 bottom = VIDEO_MAX_Y-1;

  setcolor(line_color);
  setlinestyle(line_style,0,line_size);
  rectangle(left,top,right,bottom);
}


